#ifndef EA_TFT_H
#define EA_TFT_H

#include "EA_TFT_def.h"

//----------------------------------------------------------------------------
/*! \brief Initialsize the SPI interface and resets the TFT module
 * \ingroup EA_TFT
 * \param tfttyp Modul: EA_TFT009 | EA_TFT015 | EA_TFT020 | EA_TFT024 | EA_TFT028 | EA_TFT035
 * \param clk SPI-Frequency in Hz (max. 16000000)
 */
extern void TFTspi_init (int16_t tfttyp, uint clk);


//----------------------------------------------------------------------------
/*! \brief TFT module Hardware Reset and intitialisation (TFTinit)
 * \ingroup EA_TFT
 * \param tfttyp Modul: EA_TFT009 | EA_TFT015 | EA_TFT020 | EA_TFT024 | EA_TFT028 | EA_TFT035
 */
extern void TFTreset (int16_t tfttyp);


//----------------------------------------------------------------------------
/*! \brief TFT module intitialisation without Hardware Reset
 * \ingroup EA_TFT
 * \param tfttyp Modul: EA_TFT009 | EA_TFT015 | EA_TFT020 | EA_TFT024 | EA_TFT028 | EA_TFT035
 */
extern void TFTinit (int16_t tfttyp);


//----------------------------------------------------------------------------
/*! \brief Fill the complete display area with a color
 * \ingroup EA_TFT
 * \param color 16-Bit color (you can use RGB565(r,g,b) to convert 8-Bit RGB-values)
 */
extern void TFTclear (uint16_t color);


/*! \brief Fill a rectangle area with a color
 * \ingroup EA_TFT
 * \param color 16-Bit color (you can use RGB565(r,g,b) to convert 8-Bit RGB-values)
 * \param xs x start coordinate
 * \param ys y start coordinate
 * \param xe x end coordinate
 * \param ye y end coordinate
 */
extern void TFTfill (uint16_t color, int16_t xs, int16_t ys, int16_t xe, int16_t ye);


//----------------------------------------------------------------------------
/*! \brief Output of an Text with actual font and color
 * \ingroup EA_TFT
 * \param xs x start coordinate
 * \param ys y start coordinate
 * \param ptext  pointer to an ascii-string (ending with zero)
 */
extern void TFTtext	(int16_t xs, int16_t ys, uint8_t *ptext);

//----------------------------------------------------------------------------
/*! \brief Output of an Text with actual font and color
 * \ingroup EA_TFT
 * \param xs x start coordinate
 * \param ys y start coordinate
 * \param format  pointer to an format-string, see printf
 * \param ...  variable parameter, see printf 
 */
extern void TFTprintf(int16_t xs, int16_t ys, uint8_t *format, ...);


//----------------------------------------------------------------------------
/*! \brief Output of an BMP-Image
 * \ingroup EA_TFT
 * \param xs x start coordinate
 * \param ys y start coordinate
 * \param pbitmap pointer to an uncompressed BMP-bitmap
 * \param xo x-offset in bitmap
 * \param yo y-offset in bitmap
 */
extern void TFTbitmap	(int16_t xs, int16_t ys, const uint8_t *pbitmap, int16_t xo, int16_t yo);


//----------------------------------------------------------------------------
//                            XX  
// +----+                   +----+     
// |    |      +------+     |    |     +------+
// | 0° |    XX| 90°  |     |180°|     | 270° |XX
// +----+      +------+     +----+     +------+
//   XX 
//----------------------------------------------------------------------------
/*! \brief Set the Orientation of the TFT module
 * \ingroup EA_TFT
 * \param angle Orientation: 0° | 90° | 180° | 270°
*/
extern void setTFTangle	(int16_t angle);


//----------------------------------------------------------------------------
/*! \brief Set the actual font for TFTtext()
 * \ingroup EA_TFT
 * \param nr Fontnumber: FONT_6X8 | FONT_7X12 | FONT_8X16 | FONT_30X38
 * \param zx zoom of font in x direction (1..4)
 * \param zy zoom of font in y direction (1..4)
 */
extern void setTFTfont (int16_t nr, int16_t zx, int16_t zy);


//----------------------------------------------------------------------------
/*! \brief Set foreground and background color for TFTtext()
 * \ingroup EA_TFT
 * \param fg 16-Bit foreground color (you can use RGB565(R,G,B) to convert 8-Bit RGB-values)
 * \param bg 16-Bit background color (you can use RGB565(R,G,B) to convert 8-Bit RGB-values)
 */
extern void setTFTcolor	(uint16_t fg, uint16_t bg);


//------------------------------------------------------------------------------
// global variables (only for query, do not change the values)

extern int16_t  gTFTmodul, gTFTwidth, gTFTheight, gTFTAngle;


#endif  /* EA_TFT_H */
